@@ -812,7 +812,7 @@ def possibilidade_desconectar_e_fechar_janela():
                                     ).key_down(Keys.ARROW_DOWN
                                                 ).key_down(Keys.ARROW_DOWN
                                                         ).key_down(Keys.ARROW_DOWN
-                                                                ).send_keys(Keys.ENTER
+                                                                ).send_keys(Keys.ARROW_DOWN
                                                                         ).send_keys(Keys.ENTER
                                                                                     ).perform()
     
@@ -859,12 +859,13 @@ def possibilidade_desconectar_e_manter_janela():
     
     
     
-    ActionChains(drive).send_keys(Keys.ARROW_DOWN
-                                    ).send_keys(Keys.ARROW_DOWN
-                                                ).send_keys(Keys.ARROW_DOWN
-                                                        ).send_keys(Keys.ARROW_DOWN, 
-                                                                    Keys.ENTER
-                                                                        ).perform()
+    ActionChains(drive).key_down(Keys.ARROW_DOWN
+                                    ).key_down(Keys.ARROW_DOWN
+                                                ).key_down(Keys.ARROW_DOWN
+                                                        ).key_down(Keys.ARROW_DOWN
+                                                                ).send_keys(Keys.ARROW_DOWN
+                                                                        ).send_keys(Keys.ENTER
+                                                                                    ).perform()
     
     t.sleep(1)
 
